@@ -1,6 +1,6 @@
 /* vim: set noet ts=4:
  *
- * Copyright (c) 2002-2013 Martin A. Godisch <martin@godisch.de>
+ * Copyright (c) 2002-2024 Martin A. Godisch <martin@godisch.de>
  */
 
 #include <assert.h>
@@ -361,8 +361,7 @@ char *read_state(char *state)
 	}
 
 	for (line = 1;; line++) {
-		fgets(buffer, sizeof(buffer), F);
-		if (feof(F))
+		if (fgets(buffer, sizeof(buffer), F) == NULL)
 			break;
 		if ((s = strchr(buffer, '\n')))
 			*s = '\0';
@@ -435,8 +434,7 @@ void write_state(void)
 		for (line = 1;; line++) {
 			if (line > 1)
 				fputs(buffer, F);
-			fgets(buffer, sizeof(buffer), G);
-			if (feof(G))
+			if (fgets(buffer, sizeof(buffer), G) == NULL)
 				break;
 			if (buffer[0] == '#' || buffer[0] == '\n')
 				continue;
